from disc_python.disc import *
from disc_python.algoritmos import *
from disc_python.corpus import *